hfromd: Estimate tree height above ground from diameters

View source: R/hfromd.R

hfromdR Documentation

Estimate tree height above ground from diameters

Description

Estimates tree height above ground from diameters using optimization of the taper function.

Usage

hfromd(d, h, sp = "spruce", output = "h", grd_search = F)

Arguments

d

diameters (cm).

h

height above ground of diameter measurements (m).

sp

species

output

output from optimization: 'h' outputs the tree height,'d' diameter at breast height, 'all' result of optim.

grd_search

if TRUE optimization is run on a matrix of initial parameters. The result of the best fit is returned. Might give better result at cost of performance.

Value

Tree height above ground (m).

Examples


hfromd(d=c(39,27),h=c(2,7),sp="birch")

JohannesRahlf/taperNO documentation built on Feb. 17, 2025, 8:02 p.m.