volume: Calculate volume

View source: R/volume.R

volumeR Documentation

Calculate volume

Description

Calculates volume from taper model by integrating the taper function.

Usage

volume(
  dbh,
  h_top,
  h_vol_lower = NA,
  h_vol_upper = NA,
  sp = "spruce",
  with_bark = TRUE
)

Arguments

dbh

numeric vector of diameters at breast height, 1.3 m above ground (cm).

h_top

numeric vector of tree heights above ground (m).

h_vol_lower

numeric vector of lower height for stem volume calculation (m). NA in h_vol_lower is replaced by stump height (1% of h_top).

h_vol_upper

numeric vector of upper height for stem volume calculation (m). NA in h_vol_upper is replaced by h_top.

sp

species.

with_bark

calculate volume over (TRUE, default) or under bark (FALSE).

Value

Timber volume (m^3).

Examples

volume(20, 30)
volume(dbh=c(20,25,30), h_top=c(30,25,37))
volume(dbh=rep(25,11), h_top=rep(30,11),h_vol_lower=seq(0,30,3))
volume(dbh=rep(25,11), h_top=rep(30,11),h_vol_upper=seq(0,30,3))
volume(dbh=rep(25,11), h_top=rep(30,11),h_vol_lower=0,h_vol_upper=seq(0,30,3),with_bark=FALSE)

JohannesRahlf/taperNO documentation built on Feb. 17, 2025, 8:02 p.m.