| hfromd | R Documentation |
Estimates tree height above ground from diameters using optimization of the taper function.
hfromd(d, h, sp = "spruce", output = "h", grd_search = F)
d |
diameters (cm). |
h |
height above ground of diameter measurements (m). |
sp |
species |
output |
output from optimization: 'h' outputs the tree height,'d' diameter at breast height, 'all' result of optim. |
grd_search |
if TRUE optimization is run on a matrix of initial parameters. The result of the best fit is returned. Might give better result at cost of performance. |
Tree height above ground (m).
hfromd(d=c(39,27),h=c(2,7),sp="birch")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.