| kublin_nor | R Documentation |
Based on Kublin et al. 2013. A flexible stem taper and volume prediction method based on mixed-effects B-spline regression. Eur J For Res. 132(5-6):983–997 and code in Kublin & Breidenbach (https://CRAN.R-project.org/package=TapeR).
kublin_nor(Hx = NULL, Hm, Dm, mHt, sp = 1, Dx = NULL, ...)
Hx |
height above ground where to return diameters (m) |
Hm |
height above ground of measured diameters (m) |
Dm |
measured diameters (cm) |
mHt |
measured tree height (m) above ground |
sp |
species |
Dx |
or diameters (cm) for which to return a height |
... |
parameters handed over to E_DHx_HmDm_HT.f or E_HDx_HmDm_HT.f |
Allows the use of multiple diameters measured at various points along the stem to estimate taper.
When Hx is given: diameters at Hx (cm). When Dx is given: heights where d=Dx (m).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.