| taperNOR | R Documentation |
Computes stem diameters (taper) along the bole of spruce, pine, and birch in Norway. The function implements the taper equations described in Hansen et al. (2023), based on Kozak’s (1988) variable-exponent taper equation. The original article by Hansen et al. (2023) contains minor errata (e.g., missing brackets, the use of 'Log' instead of 'ln', and a sign error at 'b7' in the pine taper model), but these do not affect the present implementation.
taperNOR(h, dbh, h_top, sp = "spruce", with_bark = TRUE)
h |
A numeric vector of heights above ground (in meters) at which to return diameters. |
dbh |
Diameter at breast height (1.3 m above ground), over bark (in centimeters). |
h_top |
Total tree height (in meters). |
sp |
Character or numeric value indicating the species; recognized inputs include:
Defaults to |
with_bark |
Logical. If |
A numeric vector of diameters (in centimeters) at each height in h.
Hansen, E., Rahlf, J., Astrup, R., & Gobakken, T. (2023). Taper, volume, and bark thickness models for spruce, pine, and birch in Norway. Scandinavian Journal of Forest Research, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/02827581.2023.2243821")}.
Kozak, A. (1988). A variable-exponent taper equation. Canadian Journal of Forest Research, 18(11), 1363–1368.
barkNOR for details on bark thickness subtraction.
# Example usage:
# Calculate taper for pine, at heights 1:30 m, dbh = 20 cm, total height = 30 m:
taperNOR(h = 1:30, dbh = 20, h_top = 30, sp = "pine", with_bark = TRUE)
# To get diameters under bark:
taperNOR(h = 1:30, dbh = 20, h_top = 30, sp = "pine", with_bark = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.